@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003, 2004, 2007 GraphicsMagick Group
+  Copyright (C) 2003 - 2009 GraphicsMagick Group
   Copyright (C) 2002 ImageMagick Studio
   Copyright 1991-1999 E. I. du Pont de Nemours and Company
  
@@ -36,70 +36,6 @@ extern "C" {
 #  define MSWINDOWS
 #endif /* defined(WIN32) || defined(WIN64) */
 
-#if defined(MSWINDOWS) && !defined(__CYGWIN__)
-#  if defined(_MT) && defined(_DLL) && !defined(_MAGICKDLL_) && !defined(_LIB)
-#    define _MAGICKDLL_
-#  endif
-
-#  if defined(_MAGICKDLL_)
-#    if defined(_VISUALC_)
-#      pragma warning( disable: 4273 )  /* Disable the dll linkage warnings */
-#    endif
-#    if !defined(_MAGICKLIB_)
-#      define MagickExport  __declspec(dllimport)
-#      if defined(_VISUALC_)
-#        pragma message( "Magick lib DLL import interface" )
-#      endif
-#    else
-#      define MagickExport  __declspec(dllexport)
-#      if defined(_VISUALC_)
-#        pragma message( "Magick lib DLL export interface" )
-#      endif
-#    endif
-#  else
-#    define MagickExport
-#    if defined(_VISUALC_)
-#      pragma message( "Magick lib static interface" )
-#    endif
-#  endif
-
-#  if defined(_DLL) && !defined(_LIB)
-#    define ModuleExport  __declspec(dllexport)
-#    if defined(_VISUALC_)
-#      pragma message( "Magick module DLL export interface" ) 
-#    endif
-#  else
-#    define ModuleExport
-#    if defined(_VISUALC_)
-#      pragma message( "Magick module static interface" ) 
-#    endif
-#  endif
-
-#  define MagickGlobal __declspec(thread)
-#  if defined(_VISUALC_)
-#    pragma warning(disable : 4018)
-#    pragma warning(disable : 4244)
-#    pragma warning(disable : 4142)
-#    pragma warning(disable : 4800)
-#    pragma warning(disable : 4786)
-#  endif
-#else
-#  define MagickExport
-#  define ModuleExport
-#  define MagickGlobal
-#endif
-
-#define MaxTextExtent  2053
-#define MagickSignature  0xabacadabUL
-
-#define MagickPassFail unsigned int
-#define MagickPass     1
-#define MagickFail     0
-
-#define MagickBool     unsigned int
-#define MagickTrue     1
-#define MagickFalse    0
-
 #if defined(MAGICK_IMPLEMENTATION)
 #  if defined(MSWINDOWS)
   /* Use Visual C++ C inline method extension to improve performance */
@@ -113,54 +49,68 @@ extern "C" {
 #  include "magick/symbols.h"
 #endif /* defined(PREFIX_MAGICK_SYMBOLS) */
 
+#include "magick/common.h"
 #include "magick/magick_types.h"
-#include "magick/error.h"
-#include "magick/log.h"
-#include "magick/timer.h"
-#include "magick/image.h"
-#include "magick/channel.h"
-#include "magick/compare.h"
-#include "magick/list.h"
-#include "magick/paint.h"
-#include "magick/render.h"
-#include "magick/draw.h"
-#include "magick/gem.h"
-#include "magick/quantize.h"
-#include "magick/compress.h"
+#include "magick/analyze.h"
 #include "magick/attribute.h"
-#include "magick/command.h"
-#include "magick/utility.h"
-#include "magick/signature.h"
+#include "magick/average.h"
 #include "magick/blob.h"
+#include "magick/cdl.h"
+#include "magick/channel.h"
 #include "magick/color.h"
+#include "magick/color_lookup.h"
+#include "magick/colormap.h"
+#include "magick/command.h"
+#include "magick/compare.h"
+#include "magick/composite.h"
+#include "magick/compress.h"
+#include "magick/confirm_access.h"
 #include "magick/constitute.h"
 #include "magick/decorate.h"
+#include "magick/delegate.h"
+#include "magick/deprecate.h"
+#include "magick/describe.h"
+#include "magick/draw.h"
+#include "magick/effect.h"
 #include "magick/enhance.h"
+#include "magick/error.h"
 #include "magick/fx.h"
+#include "magick/gem.h"
+#include "magick/gradient.h"
+#include "magick/hclut.h"
+#include "magick/image.h"
+#include "magick/list.h"
+#include "magick/log.h"
+#include "magick/magic.h"
 #include "magick/magick.h"
 #include "magick/memory.h"
-#include "magick/montage.h"
-#include "magick/effect.h"
-#include "magick/resize.h"
-#include "magick/shear.h"
-#include "magick/transform.h"
-#include "magick/composite.h"
-#include "magick/registry.h"
-#include "magick/magick.h"
-#include "magick/magic.h"
-#include "magick/delegate.h"
 #include "magick/module.h"
 #include "magick/monitor.h"
+#include "magick/montage.h"
 #include "magick/operator.h"
+#include "magick/paint.h"
 #include "magick/pixel_cache.h"
 #include "magick/pixel_iterator.h"
+#include "magick/plasma.h"
 #include "magick/profile.h"
+#include "magick/quantize.h"
+#include "magick/random.h"
+#include "magick/registry.h"
+#include "magick/render.h"
+#include "magick/resize.h"
 #include "magick/resource.h"
+#include "magick/shear.h"
+#include "magick/signature.h"
+#include "magick/statistics.h"
+#include "magick/texture.h"
+#include "magick/timer.h"
+#include "magick/transform.h"
+#include "magick/type.h"
+#include "magick/utility.h"
 #include "magick/version.h"
-#include "magick/deprecate.h"
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif /* defined(__cplusplus) || defined(c_plusplus) */
 
-#endif /* !defined(_MAGICK_API_H) */
+#endif /* _MAGICK_API_H */
